@@ -123,8 +123,10 @@ class GitRepo:
     
     def addFile(self, filename):
         if os.path.exists(self.__path + '/' + filename):
+            cwd = os.getcwd()
             repo = Repository(self.__path)
-            repo.index.add(filename)
+            cwd = cwd.replace(repo.path.replace('.git/', ''), '')
+            repo.index.add((cwd + '/' if len(cwd) > 0 else '') + filename)
             repo.index.write()
             return True
         return False
@@ -226,7 +228,7 @@ class GitRepo:
                     code = FileStatus.WT_MODIFIED
                 elif codeStr == 'D':
                     code = FileStatus.WT_DELETED
-                elif codeStr == 'R':
+                elif codeStr == 'R' or codeStr == 'RM':
                     code = FileStatus.WT_RENAMED
                 else:
                     Logger.logWarn('Unimplemented file status ' + codeStr)
